@@ -60,13 +60,14 @@
 
 #include <libosso.h>
 #include <dbus/dbus-glib.h>
-#include <bt-dbus.h>
+//#include <bt-dbus.h>
 
 #include "gnokii.h"
 
 #define _(String) String
 
 struct UICStruct {
+	GtkWidget *window;
 	GtkListStore *storeNumber;
 	GtkWidget *searchEntry;
 	GtkWidget *treeNumber;
@@ -222,7 +223,7 @@ void oneResultSignal_cb(
 					
 	if (retCode == CI_NOT_FOUND) {
         text = g_strdup_printf(_("ContactInfos found nothing for %s"), (gchar *) gtk_entry_get_text(GTK_ENTRY(uic->searchEntry)));
-		hildon_banner_show_information(GTK_WIDGET(gtk_widget_get_toplevel(uic->searchEntry)), GTK_STOCK_DIALOG_INFO, text);
+		hildon_banner_show_information(uic->window, GTK_STOCK_DIALOG_INFO, text);
         g_free(text);
 		dbus_g_proxy_disconnect_signal(proxy, CONTACTINFOS_DBUS_RESULTS_SIGNAL,
 			G_CALLBACK(oneResultSignal_cb), uic);
@@ -261,10 +262,13 @@ void on_menu_quit(GtkMenuItem * menuitem, UIComponents *uic) {
 }
 
 void on_menu_about(GtkMenuItem * menuitem, UIComponents *uic) {
-	gchar **authors = g_strsplit("Fred Lef\xc3\xa9v\xc3\xa8re-Laoide\n", "\n", -1);
-	GdkPixbuf *logo = gdk_pixbuf_new_from_file(ICONFILE, NULL);
-	gchar *comment = g_strdup_printf("Gnokii Compile : %x\nGnokii Runtime : %x", LIBGNOKII_VERSION,gn_lib_version());
-	gtk_show_about_dialog(GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(menuitem))),
+	const gchar *authors[] = {
+	    "Fred Lef\xc3\xa9v\xc3\xa8re-Laoide",
+	    NULL };
+	const GdkPixbuf *logo = gdk_pixbuf_new_from_file(ICONFILE, NULL);
+	const gchar *comment = g_strdup_printf("Gnokii Compile : %x\nGnokii Runtime : %x", LIBGNOKII_VERSION,gn_lib_version());
+	gtk_show_about_dialog(GTK_WINDOW(uic->window),
+		"name", "PhoneLink",
 		"version", VERSION,
 		"website", "https://garage.maemo.org/projects/phonelink/",
 		"website-label", _("Garage Page @ Maemo"),
@@ -272,11 +276,11 @@ void on_menu_about(GtkMenuItem * menuitem, UIComponents *uic) {
 		"logo", logo,
 		"comments", comment,
 		NULL);
-	g_strfreev(authors);
 	/*
+	g_strfreev(authors);
 	gdk_pixbuf_free(logo);
-	*/
 	g_free(comment);
+	*/
 }
 
 void on_menu_transform(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
@@ -914,13 +918,13 @@ void dialNumber(UIComponents * uic, gchar *number) {
 		normalizedNumber = normalizeNumber(number, uic->transformPlus);
 		if (normalizedNumber == NULL || normalizedNumber[0] == '\0') {
 			text = g_strdup_printf("Number %s is not Valid !\n", number);
-			hildon_banner_show_information(GTK_WIDGET(gtk_widget_get_toplevel(uic->searchEntry)), GTK_STOCK_DIALOG_ERROR, text);
+			hildon_banner_show_information(uic->window, GTK_STOCK_DIALOG_ERROR, text);
 			g_free(text);
 			g_free(normalizedNumber);
 			return;
 		}
 		text = g_strdup_printf("Dialing %s ...", normalizedNumber);
-		hildon_banner_show_information(GTK_WIDGET(gtk_widget_get_toplevel(uic->searchEntry)), GTK_STOCK_CONNECT, text);
+		hildon_banner_show_information(uic->window, GTK_STOCK_CONNECT, text);
 		g_free(text);
 		text=NULL;
 		guint ret = 0;
@@ -932,7 +936,7 @@ void dialNumber(UIComponents * uic, gchar *number) {
 			g_free(sipNormalizedNumber);
 		}
 		if (ret != 0) {
-			hildon_banner_show_information(GTK_WIDGET(gtk_widget_get_toplevel(uic->searchEntry)), GTK_STOCK_DIALOG_ERROR, text);
+			hildon_banner_show_information(uic->window, GTK_STOCK_DIALOG_ERROR, text);
 		}
 		g_free(text);
 		g_free(normalizedNumber);
@@ -1148,9 +1152,9 @@ gboolean key_press_cb(GtkWidget * widget, GdkEventKey * event, UIComponents *uic
     switch (event->keyval) {
     case GDK_F6:
 	if (uic->fullScreen) {
-		gtk_window_unfullscreen(GTK_WINDOW(gtk_widget_get_toplevel(widget)));
+		gtk_window_unfullscreen(GTK_WINDOW(uic->window));
 	} else {
-		gtk_window_fullscreen(GTK_WINDOW(gtk_widget_get_toplevel(widget)));
+		gtk_window_fullscreen(GTK_WINDOW(uic->window));
 	}
 	uic->fullScreen = !uic->fullScreen;
         return TRUE;
@@ -1192,6 +1196,7 @@ int main( int argc, char *argv[] ) {
         /* Create HildonAppView and set it to HildonApp */
         appview = HILDON_WINDOW( hildon_window_new());
         hildon_program_add_window( app, appview );
+	uic->window = GTK_WIDGET(appview);
 
 	g_type_init ();
 
@@ -1460,7 +1465,7 @@ int main( int argc, char *argv[] ) {
 	}
 	
 	if (uic->fullScreen) {
-		gtk_window_fullscreen(GTK_WINDOW(appview));
+		gtk_window_fullscreen(GTK_WINDOW(uic->window));
 	}
 	
 	/* Rest in gtk_main and wait for the fun to begin! */
